#
# spec file for package rubygem-rice
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
# This file was generated with a gem2rpm.yml and not just plain gem2rpm.
# All sections marked as MANUAL, license headers, summaries and descriptions
# can be maintained in that file. Please consult this file before editing any
# of those fields
#

Name:           rubygem-rice
Version:        4.2.1
Release:        1.2
%define mod_name rice
%define mod_full_name %{mod_name}-%{version}
# MANUAL
Source2:        rice-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
# /MANUAL
BuildRequires:  ruby-macros >= 5
BuildRequires:  %{ruby >= 2.5}
BuildRequires:  %{rubygem gem2rpm}
Url:            https://github.com/jasonroelofs/rice
Source:         https://rubygems.org/gems/%{mod_full_name}.gem
Source1:        gem2rpm.yml
Summary:        Ruby Interface for C++ Extensions
License:        MIT

%description
Rice is a C++ interface to Ruby's C API. It provides a type-safe and
exception-safe interface in order to make embedding Ruby and writing
Ruby extensions with C++ easier.

%prep

%build

%install
%gem_install \
  --doc-files="CHANGELOG.md COPYING README.md" \
  -f

%gem_packages

%changelog
* Mon Jan 29 2024 Dan Čermák <dan.cermak@posteo.net>
- ## 4.2.1
  * Support systems who use `#include <experimental/filesystem>` over `#include<filesystem>`. See [#197](https://github.com/jasonroelofs/rice/issues/197) and [#201](https://github.com/jasonroelofs/rice/pull/201)
  [#]# 4.2
  * Support Ruby 3.3.0.
  * Split Object.call to an explicit Object.call_kw for calling methods expecting keyword arguments.
  * Previously, if a wrapper used `keepAlive` on an argument or return value that was itself a Rice type, calling said method would segfault. We've now added an explicit exception to be thrown in this case, prevending the segfault and providing guidance on what was wrong and how to fix it. See [#193](https://github.com/jasonroelofs/rice/pull/193) and [#194](https://github.com/jasonroelofs/rice/pull/194)
  * Fix wrapping of std::shared_ptr to properly take default arguments into account.
* Fri Nov  3 2023 Dan Čermák <dan.cermak@posteo.net>
- ## 4.1
  Rice 4.1 builds on the 4.0 release and has a number of improvements that both polish Rice and extend its functionality. However, there are three incompatibilities to know about:
  * Exception handlers are now registered globally versus per module. This requires updating code that calls Class#add_handler to use register_handler instead.
  * Rename Arg#isValue to Arg#setValue and then Arg#getIsValue to Arg#isValue
  * Rename Return#isValue to Return#setValue and Return#getIsValue to Return#isValue
  New or improved functionality includes:
  * Add support for std::map, std::unordered_map, std::variant, std::monostate and std::reference_wrapper
  * Enable calling of C++ member functions that are defined in ancestor classes
  * Make it easy to wrap C++ iterators like std::vector begin and end
  * Enable creating enumerators for C++ collections like std::vector and std::map
  * Enable calling more Ruby API methods including those with a variable number of parameters such as rb_yield_values
  * Add additional C++ to Ruby exception mappings (for example, std::system_error to SystemCallError)
  * Updated documentation, including new pages for instance tracking, iterators, exceptions and newly supported STL classes
  * Add support for calling Ruby methods with keywords from Rice::Object and its descendants
  * Automatically translate C++ character arrays that start with colons to symbols (ie, ":mysymbol") when sending them to Ruby
  * Add a constructor for Rice::Module that takes a name, to enable code like Module("Kernel")
  * Fix comparison methods in Rice::Object, such as Object#is_equal, to return the correct result
  * Fix various compiler warnings
  * Remove deprecated APIs
  * Remove support for Ruby 2.5 and 2.6 which are officially out of support
  * Add support for building tests with CMake
  * And lots of other fixes and code improvements
  Rice also includes experimental support for instance tracking so that Rice maps the same C++ instance to the same Ruby instance each time it is passed to Ruby. See the documentation for more information.
* Thu Aug  4 2022 Stephan Kulow <coolo@suse.com>
  updated to version 4.0.4
  see installed CHANGELOG.md
* Tue Jan 25 2022 Stephan Kulow <coolo@suse.com>
  updated to version 4.0.3
  see installed CHANGELOG.md
* Thu Jun 24 2021 Stephan Kulow <coolo@suse.com>
  updated to version 4.0.2
  no changelog found
* Wed Jan 20 2021 Stephan Kulow <coolo@suse.com>
  updated to version 3.0.0
  no changelog found
* Mon Feb 10 2020 Stephan Kulow <coolo@suse.com>
- updated to version 2.2.0
  no changelog found
- Make build work with ruby2.7
* Fri Jun 14 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add rice-rpmlintrc to src.rpm
* Sat Mar  2 2019 Stephan Kulow <coolo@suse.com>
- updated to version 2.1.3
  no changelog found
* Thu Feb  8 2018 factory-auto@kulow.org
- updated to version 2.1.2
  no changelog found
* Wed Mar 22 2017 coolo@suse.com
- updated to version 2.1.1
  no changelog found
* Thu Mar 16 2017 bwiedemann@suse.com
- update with gem2rpm.yml
* Mon Jan 23 2017 bwiedemann@suse.com
- drop useless build files containing buildroot
  that confuse build-compare
* Sun May 17 2015 ms@suse.com
- Update to version 1.7.0
- Fixed gcc type cast bugs
- Fixed gem bundle for ruby 2.2
* Tue Feb 10 2015 schwab@suse.de
- Fix architecture name
- Don't package autoconf cache
- Unpack sources to update config.guess
* Tue Dec 30 2014 ms@suse.com
- build gem version 1.6.3
